# BR Logs API Wrapper
An easy way to interact with BR-Logs API. The library is built using asynchronous code, which allows for faster and efficient flow.

### Available Features:

- Get a total count of admin-actions of an administrator, for a given set of time.
- Get a total count of events on a server.

### More features will be added if needed.